@@ -1,13 +1,16 @@
 from __future__ import absolute_import
 
-__all__ = ["ZipFile", "compute_md5", "parse_assignments"]
+__all__ = [
+    "compute_md5", "parse_assignments", "substitute_variable",
+    "substitute_variables", "tempdir"
+]
 
 import hashlib
 
-import six
-
-from .misc import parse_assignments
-from ._compat import ZipFile
+from .misc import (
+    parse_assignments, substitute_variable, substitute_variables, tempdir
+)
+from .py3compat import string_types
 
 
 def compute_md5(path):
@@ -21,8 +24,25 @@ def compute_md5(path):
         If a string, assumed to be the path to the file to be checksumed. If a
         file object, checksum will start at the current file position.
     """
+    return _compute_hash(path, hashlib.md5())
+
+
+def compute_sha256(path):
+    """Compute the sha256 checksum of the given path.
+
+    Avoids reading the whole file in RAM, and computes the sha256 in chunks.
+
+    Parameters
+    ----------
+    path: str or file object
+        If a string, assumed to be the path to the file to be checksumed. If a
+        file object, checksum will start at the current file position.
+    """
+    return _compute_hash(path, hashlib.sha256())
+
+
+def _compute_hash(path, m):
     block_size = 256 * 1024
-    m = hashlib.md5()
 
     def _compute_checksum(fp):
         while True:
@@ -32,7 +52,7 @@ def compute_md5(path):
                 break
         return m.hexdigest()
 
-    if isinstance(path, six.string_types):
+    if isinstance(path, string_types):
         with open(path, "rb") as fp:
             return _compute_checksum(fp)
     else:
